## 0.0.3 (2022-01-25)


### Features

* **bert:** add tokenizer part ([550a154](https://github.com/mmmwhy/pure_attention/commit/550a154d8f563341a01e0930add37a6745d4ecaf))
* **layers:** fix import for layerNorm ([eb61b31](https://github.com/mmmwhy/pure_attention/commit/eb61b313458ac18bf4b15271fee2cf7e39f8afde))
* **nlp:** init basic bert code ([f9cb13a](https://github.com/mmmwhy/pure_attention/commit/f9cb13a3e811eb8c44ba8ff1373d688311426927))



